pysonio
=======

[pysonio](https://github.com/jayme-github/pysonio) is a python library
that provides minimalistic (and incomplete as of now) access to
time-tracking data in Personio.

Installation
------------

```
pip install git+https://github.com/jayme-github/pysonio.git
```
